button[name="flags_select_all"] {
    background: var(--primary);
    border: none;
    border-radius: 4px;
    color: #fff;
    cursor: pointer;
    margin: 0 10px 0 0;
    position: relative;
}

ul.flags-elements {
    margin-bottom: 0;
    margin-top: 0;
}

ul.flags-elements li {
    display: inline-block;
}

ul.flags-elements label input[type="checkbox"] {
    vertical-align: middle;
}
